##  Vendor Lifecycle Dates
In workspaces with the SAP LeanIX Technology Risk and Compliance product, the reference catalog provides vendor lifecycle information for IT components in addition to base attributes.
The following vendor lifecycle dates, which are relevant for obsolescence risk management initiatives, appear on IT component fact sheets:
  * Active
  * End of (Standard) Support
  * End of Extended Support Agreement
  * End of Extended Support Offering


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio99ee0555192d4c6889577f728c3e4ff6_LowRes.png)
Vendor Lifecycle Dates on a Fact Sheet
The table below lists vendor lifecycle dates and their definitions.
Vendor Lifecycle Dates Vendor Lifecycle Date | Definition | Appears on Fact Sheets
---|---|---
Alpha | The date of the first, unstable stage of an IT component lifecycle, in which basic functionality is tested. It's usually not publicly released, has limited functionality, and receives frequent updates. | No
Beta | The date of the second, stable stage of an IT component's lifecycle. It's often released to more users, including external testers, to gather usage feedback. | No
Active | The date an IT component is generally available for commercial use and eligible for support and maintenance services. | Yes
End of Sale | The date a product or version is no longer sold or manufactured by its vendor. Support services may still be available for some time. | No
End of (Standard) Support |  The date a vendor limits the support and maintenance of an IT component, transitioning it into a state of potential obsolescence risk due to its end of life, and stops providing regular updates for all users. Some vendors may provide optional extended support to give users more time to upgrade to newer versions. To document this information, use the End of Extended Support Agreement field. | Yes
End of Extended Support Agreement |  The date when an individual agreement with the vendor for extended support of IT components ends. The product or version transitions into an unsupported phase, which poses an obsolescence risk. This field is editable and isn't provided by the reference catalog. | Yes
End of Extended Support Offering |  The date that marks the transition of a product or product version into an unsupported state. After this date, support and security updates are no longer available. To view this date, hover over the question mark icon next to the End of Extended Support Agreement field in the Lifecycle section on an IT component fact sheet. The end date of the extended support offering appears in a tooltip. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio6b2be99ce2ea4206b48abfcd09e2a578_LowRes.png) End of Extended Vendor Support Offering Shown on a Fact Sheet To store information on your organization’s individual extended support agreement, use the End of Extended Support Agreement field. This field is editable and isn't provided by the reference catalog. | Yes


### Legacy Names of Vendor Lifecycle Dates
On August 21, 2025, the default names of vendor lifecycle dates changed to reduce ambiguity and avoid confusion with internal lifecycle phases of fact sheets. The table below lists the previous and current names.
Legacy and Current Names of Vendor Lifecycle Dates Legacy Name | Current Name
---|---
Plan | Alpha
Phase In | Beta
Active (Vendor) | Active
Phase Out | End of Sale
End of Life (Vendor) | End of (Standard) Support
Extended Vendor Support Agreement | End of Extended Support Agreement
Last Date of Paid Support post End of Life | End of Extended Support Offering


